Summary: A free and portable font rendering engine
Name: freetype2
Version: 2.5.0
Release: 1
License: BSD/GPL dual license
Group: System Environment/Libraries
URL: http://www.freetype.org

Source0: http://download.savannah.gnu.org/releases/freetype/freetype-%{version}.1.tar.bz2
Source1: http://download.savannah.gnu.org/releases/freetype/freetype-%{version}.1.tar.bz2.sig
Source2: http://download.savannah.gnu.org/releases/freetype/freetype-doc-%{version}.tar.bz2
Source3: http://download.savannah.gnu.org/releases/freetype/freetype-doc-%{version}.tar.bz2.sig
Source4: http://download.savannah.gnu.org/releases/freetype/ft2demos-%{version}.tar.bz2
Source5: http://download.savannah.gnu.org/releases/freetype/ft2demos-%{version}.tar.bz2.sig

BuildRequires: zlib-devel, coreutils
Requires: zlib

Buildroot: %{_tmppath}/%{name}-%{version}-%{release}-root

%description
The FreeType engine is a free and portable font rendering
engine, developed to provide advanced font support for a variety of
platforms and environments. FreeType is a library which can open and
manages font files as well as efficiently load, hint and render
individual glyphs. FreeType is not a font server or a complete
text-rendering library.

The library is available as 32-bit and 64-bit.


%package demos
Summary: A collection of FreeType demos
Group: System Environment/Libraries
Requires: %{name} = %{version}-%{release}

%description demos
The FreeType engine is a free and portable font rendering
engine, developed to provide advanced font support for a variety of
platforms and environments.  The demos package includes a set of useful
small utilities showing various capabilities of the FreeType library.


%package devel
Summary: FreeType development libraries and header files
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}
Requires: zlib-devel
Requires: pkg-config

%description devel
The freetype-devel package includes the static libraries and header files
for the FreeType font rendering engine.

Install freetype-devel if you want to develop programs which will use
FreeType.

If you are compiling a 32-bit program, no special compiler options are
needed.

If you are compiling a 64-bit program, you have to compile and link your
application with "cc -q64" or "gcc -maix64".


%prep
%setup -q -n freetype-%{version}.1 -b 2 -a 4


%build
export CONFIG_SHELL=/usr/bin/ksh
export CONFIG_ENV_ARGS=/usr/bin/ksh

# setup environment for 32-bit and 64-bit builds
export AR="ar -X32_64"
export NM="nm -X32_64"

# first build the 64-bit version
export CC="cc -q64"
GNUMAKE=gmake ./configure \
    --prefix=%{_prefix} \
    --enable-shared --enable-static
gmake %{?_smp_mflags}

cp objs/.libs/libfreetype.so.6 .
gmake distclean

# now build the 32-bit version
export CC="cc"
GNUMAKE=gmake ./configure \
    --prefix=%{_prefix} \
    --enable-shared --enable-static
gmake %{?_smp_mflags}

# add the 64-bit shared objects to the shared library containing already the
# 32-bit shared objects
${AR} -q objs/.libs/libfreetype.a ./libfreetype.so.6

# Build demos
cd ft2demos-%{version}
gmake TOP_DIR=".." %{?_smp_mflags}


%install
export PATH=/opt/freeware/bin:$PATH

[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}
gmake DESTDIR=${RPM_BUILD_ROOT} install

for f in ftbench ftdiff ftdump ftgamma ftgrid ftlint \
         ftmulti ftstring ftvalid ftview ; do
    builds/unix/libtool --mode=install install -m 755 ft2demos-%{version}/bin/${f} ${RPM_BUILD_ROOT}%{_bindir}
done

/usr/bin/strip ${RPM_BUILD_ROOT}%{_bindir}/* || :

(
  cd ${RPM_BUILD_ROOT}
  for dir in bin include lib
  do
    mkdir -p usr/${dir}
    cd usr/${dir}
    ln -sf ../..%{_prefix}/${dir}/* .
    cd -
  done
)


%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,system)
%doc ChangeLog README
%{_libdir}/*.a
/usr/lib/*.a


%files demos
%defattr(-,root,system)
%{_bindir}/ft*
/usr/bin/ft*


%files devel
%defattr(-,root,system)
%{_bindir}/freetype-config
%{_includedir}/*
%{_libdir}/*.la
%{_libdir}/pkgconfig/*.pc
%{_datadir}/aclocal/*
/usr/bin/freetype-config
/usr/include/*
/usr/lib/*.la


%changelog
* Thu Jun 20 2013 Michael Perzl <michael@perzl.org> - 2.5.0-1
- updated to version 2.5.0

* Mon Jun 17 2013 Michael Perzl <michael@perzl.org> - 2.4.12-1
- updated to version 2.4.12

* Mon Jan 07 2013 Michael Perzl <michael@perzl.org> - 2.4.11-1
- updated to version 2.4.11

* Tue Jun 19 2012 Michael Perzl <michael@perzl.org> - 2.4.10-1
- updated to version 2.4.10

* Tue Jun 19 2012 Michael Perzl <michael@perzl.org> - 2.4.10-1
- updated to version 2.4.10

* Wed Mar 14 2012 Michael Perzl <michael@perzl.org> - 2.4.9-1
- updated to version 2.4.9

* Wed Nov 16 2011 Michael Perzl <michael@perzl.org> - 2.4.8-1
- updated to version 2.4.8

* Mon Nov 07 2011 Michael Perzl <michael@perzl.org> - 2.4.7-1
- updated to version 2.4.7

* Mon Aug 01 2011 Michael Perzl <michael@perzl.org> - 2.4.6-1
- updated to version 2.4.6

* Mon Jun 27 2011 Michael Perzl <michael@perzl.org> - 2.4.5-1
- updated to version 2.4.5

* Mon Dec 06 2010 Michael Perzl <michael@perzl.org> - 2.4.4-1
- updated to version 2.4.4

* Thu Oct 07 2010 Michael Perzl <michael@perzl.org> - 2.4.3-1
- updated to version 2.4.3

* Thu Aug 26 2010 Michael Perzl <michael@perzl.org> - 2.4.2-1
- updated to version 2.4.2

* Tue Aug 03 2010 Michael Perzl <michael@perzl.org> - 2.4.1-1
- updated to version 2.4.1

* Tue Jul 13 2010 Michael Perzl <michael@perzl.org> - 2.4.0-1
- updated to version 2.4.0

* Thu Apr 08 2010 Michael Perzl <michael@perzl.org> - 2.3.12-1
- updated to version 2.3.12

* Tue Nov 17 2009 Michael Perzl <michael@perzl.org> - 2.3.11-1
- updated to version 2.3.11

* Tue Jul 07 2009 Michael Perzl <michael@perzl.org> - 2.3.9-1
- updated to version 2.3.9

* Fri Jan 16 2009 Michael Perzl <michael@perzl.org> - 2.3.8-1
- updated to version 2.3.8

* Mon Jul 07 2008 Michael Perzl <michael@perzl.org> - 2.3.7-1
- updated to version 2.3.7

* Tue Jun 24 2008 Michael Perzl <michael@perzl.org> - 2.3.6-1
- updated to version 2.3.6

* Sat Mar 28 2008 Michael Perzl <michael@perzl.org> - 2.3.5-1
- first version for AIX V5.1 and higher
